@@ -1,4 +1,4 @@
-from django.urls import include, path
+from django.urls import path
 from . import views
 
 app_name = "netvis"
@@ -7,6 +7,4 @@ urlpatterns = [
     path('graph/<app_name>/<model_name>/<pk>', views.graph_data, name='graph'),
     path('graph/<app_name>/<model_name>', views.qs_graph_data, name='qs_as_graph'),
     path('cached/<app_name>/<model_name>', views.cashed_graph_data, name='cached_graph'),
-    path('preview/<app_name>/<model_name>', views.preview_graph_data, name='preview_graph'),
-    path('<app_name>/<model_name>', views.CachednetvisView.as_view(), name='cached_graph_html'),
 ]
